spawn_reader_with_input

Function spawn_reader_with_input 

pub fn spawn_reader_with_input(
    shared: Arc<DapShared>,
    bp_state: Arc<Mutex<BreakpointState>>,
    input: Box<dyn Read + Send>,
) -> (JoinHandle<()>, Receiver<LaunchParams>)
Spawn the DAP reader thread reading from an arbitrary Read source (stdin for stdio mode; a TCP socket for socket mode). Returns a join handle and a “launch parameters” channel that the main thread blocks on before starting the VM.