pub fn parse_format_template(lines: &[String]) -> PerlResult<FormatTemplate>Expand description
Build a template from raw lines between format N = and ..
pub fn parse_format_template(lines: &[String]) -> PerlResult<FormatTemplate>Build a template from raw lines between format N = and ..