Parser

Struct Parser 

pub struct Parser {
    pub suppress_m_regex: u32,
    pub parsing_module: bool,
    pub bare_positional_indices: HashSet<usize>,
    /* private fields */
}

Fields

suppress_m_regex: u32

When > 0, the lexer should not interpret m/, s/, etc. as regex-starters. Used by thread macro to prevent /m/ from being misparsed.

parsing_module: bool

When true, we’re parsing a module (via use/require), not user code. Modules are allowed to shadow builtins; user code is not (unless --compat).

bare_positional_indices: HashSet<usize>

Token-vector indices where the lexer emitted a bare positional alias (_, _0, _1, …) — i.e. without a leading $ sigil. Populated by crate::lexer::Lexer::tokenize. Consulted by Self::parse_my_our_local to auto-wrap an RHS expression that contains free positional aliases into an implicit zero-arg coderef, so my $f = _ * 2my $f = fn { _ * 2 }.

Implementations

Source

impl Parser

pub fn new(tokens: Vec<(Token, usize)>) -> Self

pub fn new_with_file( tokens: Vec<(Token, usize)>, file: impl Into<String>, ) -> Self

pub fn parse_program(&mut self) -> PerlResult<Program>

pub fn parse_statements(&mut self) -> PerlResult<Vec<Statement>>

Parse statements until EOF. Used by parse_program and parse_block_from_str.