pub fn try_load(path: &Path) -> Option<CachedScript>Expand description
Try to load a cached script by source path. Returns None on any miss.
pub fn try_load(path: &Path) -> Option<CachedScript>Try to load a cached script by source path. Returns None on any miss.