pub struct ScriptEntry {
pub mtime_secs: i64,
pub mtime_nsecs: i64,
pub binary_mtime_at_cache: i64,
pub cached_at_secs: i64,
pub program_blob: Vec<u8>,
pub chunk_blob: Vec<u8>,
}Fields
mtime_secs: i64mtime_nsecs: i64binary_mtime_at_cache: i64cached_at_secs: i64program_blob: Vec<u8>chunk_blob: Vec<u8>Trait Implementations
Sourceimpl Archive for ScriptEntry
impl Archive for ScriptEntry
Sourcetype Archived = ArchivedScriptEntry
type Archived = ArchivedScriptEntry
The archived representation of this type. Read more
Sourcetype Resolver = ScriptEntryResolver
type Resolver = ScriptEntryResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ScriptEntry
impl Clone for ScriptEntry
Sourcefn clone(&self) -> ScriptEntry
fn clone(&self) -> ScriptEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScriptEntry
impl Debug for ScriptEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ScriptEntry, __D> for Archived<ScriptEntry>
impl<__D: Fallible + ?Sized> Deserialize<ScriptEntry, __D> for Archived<ScriptEntry>
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<ScriptEntry, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<ScriptEntry, __D::Error>
Deserializes using the given deserializer