pub struct ScriptShard {
pub header: ShardHeader,
pub entries: HashMap<String, ScriptEntry>,
}Fields
header: ShardHeaderentries: HashMap<String, ScriptEntry>Trait Implementations
Sourceimpl Archive for ScriptShard
impl Archive for ScriptShard
Sourcetype Archived = ArchivedScriptShard
type Archived = ArchivedScriptShard
The archived representation of this type. Read more
Sourcetype Resolver = ScriptShardResolver
type Resolver = ScriptShardResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ScriptShard
impl Clone for ScriptShard
Sourcefn clone(&self) -> ScriptShard
fn clone(&self) -> ScriptShard
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScriptShard
impl Debug for ScriptShard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ScriptShard, __D> for Archived<ScriptShard>where
ShardHeader: Archive,
Archived<ShardHeader>: Deserialize<ShardHeader, __D>,
HashMap<String, ScriptEntry>: Archive,
Archived<HashMap<String, ScriptEntry>>: Deserialize<HashMap<String, ScriptEntry>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ScriptShard, __D> for Archived<ScriptShard>where
ShardHeader: Archive,
Archived<ShardHeader>: Deserialize<ShardHeader, __D>,
HashMap<String, ScriptEntry>: Archive,
Archived<HashMap<String, ScriptEntry>>: Deserialize<HashMap<String, ScriptEntry>, __D>,
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<ScriptShard, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<ScriptShard, __D::Error>
Deserializes using the given deserializer