pub struct ShardHeader {
pub magic: u32,
pub format_version: u32,
pub stryke_version: String,
pub pointer_width: u32,
pub built_at_secs: u64,
}Fields
magic: u32format_version: u32stryke_version: Stringpointer_width: u32built_at_secs: u64Trait Implementations
Sourceimpl Archive for ShardHeader
impl Archive for ShardHeader
Sourcetype Archived = ArchivedShardHeader
type Archived = ArchivedShardHeader
The archived representation of this type. Read more
Sourcetype Resolver = ShardHeaderResolver
type Resolver = ShardHeaderResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ShardHeader
impl Clone for ShardHeader
Sourcefn clone(&self) -> ShardHeader
fn clone(&self) -> ShardHeader
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShardHeader
impl Debug for ShardHeader
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShardHeader, __D> for Archived<ShardHeader>
impl<__D: Fallible + ?Sized> Deserialize<ShardHeader, __D> for Archived<ShardHeader>
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<ShardHeader, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<ShardHeader, __D::Error>
Deserializes using the given deserializer