execcmd_getargs

Function execcmd_getargs 

pub fn execcmd_getargs(
    preargs: &mut LinkList<String>,
    args: &mut LinkList<String>,
    expand: i32,
)
Port of execcmd_getargs(LinkList preargs, LinkList args, int expand) from Src/exec.c:2791-2806. Transfer the first node of args to preargs, performing prefork (singleton-list expansion) on the way if expand is set. Used by execcmd_exec to pull the command head one word at a time so prefix-modifier walking (BINF_COMMAND, BINF_EXEC etc.) sees expanded names.