BorrowedFdFile

Struct BorrowedFdFile 

pub struct BorrowedFdFile(/* private fields */);
A File wrapper that doesn’t close on drop (borrows the fd).

Implementations

Methods from Deref<Target = File>

1.0.0 · Source

pub fn sync_all(&self) -> Result<(), Error>

Attempts to sync all OS-internal file content and metadata to disk.

This function will attempt to ensure that all in-memory data reaches the filesystem before returning.

This can be used to handle errors that would otherwise only be caught when the File is closed, as dropping a File will ignore all errors. Note, however, that sync_all is generally more expensive than closing a file by dropping it, because the latter is not required to block until the data has been written to the filesystem.

If synchronizing the metadata is not required, use sync_data instead.

Examples
use std::fs::File;
use std::io::prelude::*;

fn main() -> std::io::Result<()> {
    let mut f = File::create("foo.txt")?;
    f.write_all(b"Hello, world!")?;

    f.sync_all()?;
    Ok(())
}
1.0.0 · Source

pub fn sync_data(&self) -> Result<(), Error>

This function is similar to sync_all, except that it might not synchronize file metadata to the filesystem.

This is intended for use cases that must synchronize content, but don’t need the metadata on disk. The goal of this method is to reduce disk operations.

Note that some platforms may simply implement this in terms of sync_all.

Examples
use std::fs::File;
use std::io::prelude::*;

fn main() -> std::io::Result<()> {
    let mut f = File::create("foo.txt")?;
    f.write_all(b"Hello, world!")?;

    f.sync_data()?;
    Ok(())
}
1.89.0 · Source

pub fn lock(&self) -> Result<(), Error>

Acquire an exclusive lock on the file. Blocks until the lock can be acquired.

This acquires an exclusive lock; no other file handle to this file, in this or any other process, may acquire another lock.

This lock may be advisory or mandatory. This lock is meant to interact with lock, try_lock, lock_shared, try_lock_shared, and unlock. Its interactions with other methods, such as read and write are platform specific, and it may or may not cause non-lockholders to block.

If this file handle/descriptor, or a clone of it, already holds a lock the exact behavior is unspecified and platform dependent, including the possibility that it will deadlock. However, if this method returns, then an exclusive lock is held.

If the file is not open for writing, it is unspecified whether this function returns an error.

The lock will be released when this file (along with any other file descriptors/handles duplicated or inherited from it) is closed, or if the unlock method is called.

Platform-specific behavior

This function currently corresponds to the flock function on Unix with the LOCK_EX flag, and the LockFileEx function on Windows with the LOCKFILE_EXCLUSIVE_LOCK flag. Note that, this may change in the future.

On Windows, locking a file will fail if the file is opened only for append. To lock a file, open it with one of .read(true), .read(true).append(true), or .write(true).

Examples
use std::fs::File;

fn main() -> std::io::Result<()> {
    let f = File::create("foo.txt")?;
    f.lock()?;
    Ok(())
}
1.89.0 · Source

pub fn lock_shared(&self) -> Result<(), Error>

Acquire a shared (non-exclusive) lock on the file. Blocks until the lock can be acquired.

This acquires a shared lock; more than one file handle, in this or any other process, may hold a shared lock, but none may hold an exclusive lock at the same time.

This lock may be advisory or mandatory. This lock is meant to interact with lock, try_lock, lock_shared, try_lock_shared, and unlock. Its interactions with other methods, such as read and write are platform specific, and it may or may not cause non-lockholders to block.

If this file handle/descriptor, or a clone of it, already holds a lock, the exact behavior is unspecified and platform dependent, including the possibility that it will deadlock. However, if this method returns, then a shared lock is held.

The lock will be released when this file (along with any other file descriptors/handles duplicated or inherited from it) is closed, or if the unlock method is called.

Platform-specific behavior

This function currently corresponds to the flock function on Unix with the LOCK_SH flag, and the LockFileEx function on Windows. Note that, this may change in the future.

On Windows, locking a file will fail if the file is opened only for append. To lock a file, open it with one of .read(true), .read(true).append(true), or .write(true).

Examples
use std::fs::File;

fn main() -> std::io::Result<()> {
    let f = File::open("foo.txt")?;
    f.lock_shared()?;
    Ok(())
}
1.89.0 · Source

pub fn try_lock(&self) -> Result<(), TryLockError>

Try to acquire an exclusive lock on the file.

Returns Err(TryLockError::WouldBlock) if a different lock is already held on this file (via another handle/descriptor).

This acquires an exclusive lock; no other file handle to this file, in this or any other process, may acquire another lock.

This lock may be advisory or mandatory. This lock is meant to interact with lock, try_lock, lock_shared, try_lock_shared, and unlock. Its interactions with other methods, such as read and write are platform specific, and it may or may not cause non-lockholders to block.

If this file handle/descriptor, or a clone of it, already holds a lock, the exact behavior is unspecified and platform dependent, including the possibility that it will deadlock. However, if this method returns Ok(()), then it has acquired an exclusive lock.

If the file is not open for writing, it is unspecified whether this function returns an error.

The lock will be released when this file (along with any other file descriptors/handles duplicated or inherited from it) is closed, or if the unlock method is called.

Platform-specific behavior

This function currently corresponds to the flock function on Unix with the LOCK_EX and LOCK_NB flags, and the LockFileEx function on Windows with the LOCKFILE_EXCLUSIVE_LOCK and LOCKFILE_FAIL_IMMEDIATELY flags. Note that, this may change in the future.

On Windows, locking a file will fail if the file is opened only for append. To lock a file, open it with one of .read(true), .read(true).append(true), or .write(true).

Examples
use std::fs::{File, TryLockError};

fn main() -> std::io::Result<()> {
    let f = File::create("foo.txt")?;
    // Explicit handling of the WouldBlock error
    match f.try_lock() {
        Ok(_) => (),
        Err(TryLockError::WouldBlock) => (), // Lock not acquired
        Err(TryLockError::Error(err)) => return Err(err),
    }
    // Alternately, propagate the error as an io::Error
    f.try_lock()?;
    Ok(())
}
1.89.0 · Source

pub fn try_lock_shared(&self) -> Result<(), TryLockError>

Try to acquire a shared (non-exclusive) lock on the file.

Returns Err(TryLockError::WouldBlock) if a different lock is already held on this file (via another handle/descriptor).

This acquires a shared lock; more than one file handle, in this or any other process, may hold a shared lock, but none may hold an exclusive lock at the same time.

This lock may be advisory or mandatory. This lock is meant to interact with lock, try_lock, lock_shared, try_lock_shared, and unlock. Its interactions with other methods, such as read and write are platform specific, and it may or may not cause non-lockholders to block.

If this file handle, or a clone of it, already holds a lock, the exact behavior is unspecified and platform dependent, including the possibility that it will deadlock. However, if this method returns Ok(()), then it has acquired a shared lock.

The lock will be released when this file (along with any other file descriptors/handles duplicated or inherited from it) is closed, or if the unlock method is called.

Platform-specific behavior

This function currently corresponds to the flock function on Unix with the LOCK_SH and LOCK_NB flags, and the LockFileEx function on Windows with the LOCKFILE_FAIL_IMMEDIATELY flag. Note that, this may change in the future.

On Windows, locking a file will fail if the file is opened only for append. To lock a file, open it with one of .read(true), .read(true).append(true), or .write(true).

Examples
use std::fs::{File, TryLockError};

fn main() -> std::io::Result<()> {
    let f = File::open("foo.txt")?;
    // Explicit handling of the WouldBlock error
    match f.try_lock_shared() {
        Ok(_) => (),
        Err(TryLockError::WouldBlock) => (), // Lock not acquired
        Err(TryLockError::Error(err)) => return Err(err),
    }
    // Alternately, propagate the error as an io::Error
    f.try_lock_shared()?;

    Ok(())
}
1.89.0 · Source

pub fn unlock(&self) -> Result<(), Error>

Release all locks on the file.

All locks are released when the file (along with any other file descriptors/handles duplicated or inherited from it) is closed. This method allows releasing locks without closing the file.

If no lock is currently held via this file descriptor/handle, this method may return an error, or may return successfully without taking any action.

Platform-specific behavior

This function currently corresponds to the flock function on Unix with the LOCK_UN flag, and the UnlockFile function on Windows. Note that, this may change in the future.

On Windows, locking a file will fail if the file is opened only for append. To lock a file, open it with one of .read(true), .read(true).append(true), or .write(true).

Examples
use std::fs::File;

fn main() -> std::io::Result<()> {
    let f = File::open("foo.txt")?;
    f.lock()?;
    f.unlock()?;
    Ok(())
}
1.0.0 · Source

pub fn set_len(&self, size: u64) -> Result<(), Error>

Truncates or extends the underlying file, updating the size of this file to become size.

If the size is less than the current file’s size, then the file will be shrunk. If it is greater than the current file’s size, then the file will be extended to size and have all of the intermediate data filled in with 0s.

The file’s cursor isn’t changed. In particular, if the cursor was at the end and the file is shrunk using this operation, the cursor will now be past the end.

Errors

This function will return an error if the file is not opened for writing. Also, std::io::ErrorKind::InvalidInput will be returned if the desired length would cause an overflow due to the implementation specifics.

Examples
use std::fs::File;

fn main() -> std::io::Result<()> {
    let mut f = File::create("foo.txt")?;
    f.set_len(10)?;
    Ok(())
}

Note that this method alters the content of the underlying file, even though it takes &self rather than &mut self.

1.0.0 · Source

pub fn metadata(&self) -> Result<Metadata, Error>

Queries metadata about the underlying file.

Examples
use std::fs::File;

fn main() -> std::io::Result<()> {
    let mut f = File::open("foo.txt")?;
    let metadata = f.metadata()?;
    Ok(())
}
1.9.0 · Source

pub fn try_clone(&self) -> Result<File, Error>

Creates a new File instance that shares the same underlying file handle as the existing File instance. Reads, writes, and seeks will affect both File instances simultaneously.

Examples

Creates two handles for a file named foo.txt:

use std::fs::File;

fn main() -> std::io::Result<()> {
    let mut file = File::open("foo.txt")?;
    let file_copy = file.try_clone()?;
    Ok(())
}

Assuming there’s a file named foo.txt with contents abcdef\n, create two handles, seek one of them, and read the remaining bytes from the other handle:

use std::fs::File;
use std::io::SeekFrom;
use std::io::prelude::*;

fn main() -> std::io::Result<()> {
    let mut file = File::open("foo.txt")?;
    let mut file_copy = file.try_clone()?;

    file.seek(SeekFrom::Start(3))?;

    let mut contents = vec![];
    file_copy.read_to_end(&mut contents)?;
    assert_eq!(contents, b"def\n");
    Ok(())
}
1.16.0 · Source

pub fn set_permissions(&self, perm: Permissions) -> Result<(), Error>

Changes the permissions on the underlying file.

Platform-specific behavior

This function currently corresponds to the fchmod function on Unix and the SetFileInformationByHandle function on Windows. Note that, this may change in the future.

Errors

This function will return an error if the user lacks permission change attributes on the underlying file. It may also return an error in other os-specific unspecified cases.

Examples
fn main() -> std::io::Result<()> {
    use std::fs::File;

    let file = File::open("foo.txt")?;
    let mut perms = file.metadata()?.permissions();
    perms.set_readonly(true);
    file.set_permissions(perms)?;
    Ok(())
}

Note that this method alters the permissions of the underlying file, even though it takes &self rather than &mut self.

1.75.0 · Source

pub fn set_times(&self, times: FileTimes) -> Result<(), Error>

Changes the timestamps of the underlying file.

Platform-specific behavior

This function currently corresponds to the futimens function on Unix (falling back to futimes on macOS before 10.13) and the SetFileTime function on Windows. Note that this may change in the future.

On most platforms, including UNIX and Windows platforms, this function can also change the timestamps of a directory. To get a File representing a directory in order to call set_times, open the directory with File::open without attempting to obtain write permission.

Errors

This function will return an error if the user lacks permission to change timestamps on the underlying file. It may also return an error in other os-specific unspecified cases.

This function may return an error if the operating system lacks support to change one or more of the timestamps set in the FileTimes structure.

Examples
fn main() -> std::io::Result<()> {
    use std::fs::{self, File, FileTimes};

    let src = fs::metadata("src")?;
    let dest = File::open("dest")?;
    let times = FileTimes::new()
        .set_accessed(src.accessed()?)
        .set_modified(src.modified()?);
    dest.set_times(times)?;
    Ok(())
}
1.75.0 · Source

pub fn set_modified(&self, time: SystemTime) -> Result<(), Error>

Changes the modification time of the underlying file.

This is an alias for set_times(FileTimes::new().set_modified(time)).