HistoryEngine

Struct HistoryEngine 

pub struct HistoryEngine { /* private fields */ }

Implementations

Source

impl HistoryEngine

pub fn new() -> Result<HistoryEngine, Error>

pub fn in_memory() -> Result<HistoryEngine, Error>

pub fn add(&self, command: &str, cwd: Option<&str>) -> Result<i64, Error>

Add a command to history, updating frequency if it already exists

pub fn update_last( &self, id: i64, duration_ms: i64, exit_code: i32, ) -> Result<(), Error>

Update the duration and exit code of the last command

pub fn search( &self, query: &str, limit: usize, ) -> Result<Vec<HistoryEntry>, Error>

Search history with FTS5 (fuzzy/substring matching)

pub fn search_prefix( &self, prefix: &str, limit: usize, ) -> Result<Vec<HistoryEntry>, Error>

Search history with prefix matching (for up-arrow completion)

pub fn recent(&self, limit: usize) -> Result<Vec<HistoryEntry>, Error>

Get recent history entries

pub fn for_directory( &self, cwd: &str, limit: usize, ) -> Result<Vec<HistoryEntry>, Error>

Get history for a specific directory

pub fn delete(&self, id: i64) -> Result<(), Error>

Delete a history entry

pub fn clear(&self) -> Result<(), Error>

Clear all history

pub fn count(&self) -> Result<i64, Error>

Get total history count

pub fn get_by_offset( &self, offset: usize, ) -> Result<Option<HistoryEntry>, Error>

Get entry by index from end (0 = most recent, like !-1)

pub fn get_by_number(&self, num: i64) -> Result<Option<HistoryEntry>, Error>

Get entry by absolute history number (like !123)