pub struct JobTable { /* private fields */ }Expand description
Job table compatible with exec.rs
Implementations
Sourceimpl JobTable
impl JobTable
pub fn new() -> JobTable
Sourcepub fn peek_next_id(&self) -> usize
pub fn peek_next_id(&self) -> usize
Peek at the next id that would be assigned by add_job/add_pid.
Used by wait %N to distinguish a never-issued id (clear user
error) from a job that was issued and already reaped (silent
success in zshrs to keep the cmd & wait %1 idiom working
across the races introduced by the threaded job table).
Sourcepub fn add_job(
&mut self,
child: Child,
command: String,
state: JobState,
) -> usize
pub fn add_job( &mut self, child: Child, command: String, state: JobState, ) -> usize
Add a job with a Child process
Sourcepub fn iter(&self) -> impl Iterator<Item = (usize, &JobInfo)>
pub fn iter(&self) -> impl Iterator<Item = (usize, &JobInfo)>
Iterate over jobs with their IDs (for compatibility)
Sourcepub fn reap_finished(&mut self) -> Vec<JobInfo>
pub fn reap_finished(&mut self) -> Vec<JobInfo>
Reap finished jobs (check for completed processes)