empty_eprog

Function empty_eprog 

pub fn empty_eprog(p: &eprog) -> bool
Port of int empty_eprog(Eprog p) from Src/parse.c:584. C body: return (!p || !p->prog || *p->prog == WCB_END()); — the eprog is empty when its prog buffer is missing or the first wordcode is the WC_END marker. Used by signal handlers (Src/signals.c:712) to short-circuit a trap that resolves to an empty program.