pub struct BindStateFlags(/* private fields */);Implementations
Sourceimpl BindStateFlags
impl BindStateFlags
pub const LIST: BindStateFlags
pub const ALL: BindStateFlags
Sourceimpl BindStateFlags
impl BindStateFlags
Sourcepub const fn empty() -> BindStateFlags
pub const fn empty() -> BindStateFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> BindStateFlags
pub const fn all() -> BindStateFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<BindStateFlags>
pub const fn from_bits(bits: u32) -> Option<BindStateFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> BindStateFlags
pub const fn from_bits_truncate(bits: u32) -> BindStateFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> BindStateFlags
pub const fn from_bits_retain(bits: u32) -> BindStateFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<BindStateFlags>
pub fn from_name(name: &str) -> Option<BindStateFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: BindStateFlags) -> bool
pub const fn intersects(&self, other: BindStateFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: BindStateFlags) -> bool
pub const fn contains(&self, other: BindStateFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: BindStateFlags)
pub fn insert(&mut self, other: BindStateFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: BindStateFlags)
pub fn remove(&mut self, other: BindStateFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: BindStateFlags)
pub fn toggle(&mut self, other: BindStateFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: BindStateFlags, value: bool)
pub fn set(&mut self, other: BindStateFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: BindStateFlags) -> BindStateFlags
pub const fn intersection(self, other: BindStateFlags) -> BindStateFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: BindStateFlags) -> BindStateFlags
pub const fn union(self, other: BindStateFlags) -> BindStateFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: BindStateFlags) -> BindStateFlags
pub const fn difference(self, other: BindStateFlags) -> BindStateFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: BindStateFlags) -> BindStateFlags
pub const fn symmetric_difference(self, other: BindStateFlags) -> BindStateFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> BindStateFlags
pub const fn complement(self) -> BindStateFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl BindStateFlags
impl BindStateFlags
Sourcepub const fn iter(&self) -> Iter<BindStateFlags>
pub const fn iter(&self) -> Iter<BindStateFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BindStateFlags>
pub const fn iter_names(&self) -> IterNames<BindStateFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.