KeymapManager

Struct KeymapManager 

pub struct KeymapManager {
    pub keymaps: HashMap<String, Arc<Keymap>>,
    pub current: Option<Arc<Keymap>>,
    pub current_name: String,
    pub local: Option<Arc<Keymap>>,
    pub keybuf: Vec<u8>,
    pub lastnamed: Option<Thingy>,
}
Manager for all keymaps

Fields

keymaps: HashMap<String, Arc<Keymap>>

Named keymaps

current: Option<Arc<Keymap>>

Current keymap

current_name: String

Current keymap name

local: Option<Arc<Keymap>>

Local keymap (temporary override)

keybuf: Vec<u8>

Key sequence buffer

lastnamed: Option<Thingy>

Last named command executed

Implementations

Source

impl KeymapManager

pub fn new() -> KeymapManager

pub fn get(&self, name: &str) -> Option<Arc<Keymap>>

Get a keymap by name

pub fn select(&mut self, name: &str) -> bool

Set the current keymap

Link a new name to an existing keymap

pub fn delete(&mut self, name: &str) -> bool

Delete a keymap name

pub fn lookup_key(&self, c: char) -> Option<Thingy>

Look up a key in the current keymap

pub fn lookup_seq(&self, seq: &[u8]) -> Option<&KeyBinding>

Look up a key sequence in the current keymap

pub fn is_prefix(&self, seq: &[u8]) -> bool

Check if a sequence is a prefix in the current keymap

pub fn list_names(&self) -> Vec<&String>

List all keymap names Port of bin_bindkey_lsmaps() from zle_keymap.c

pub fn new_keymap(&mut self, name: &str) -> bool

Create a new empty keymap Port of newkeymap() from zle_keymap.c

pub fn copy_keymap(&mut self, src: &str, dst: &str) -> bool

Copy a keymap to a new name Port of copyto from bin_bindkey_new

pub fn select_local_map(&mut self, name: Option<&str>)

Set a local keymap (temporary override) Port of selectlocalmap() from zle_keymap.c

pub fn reselect_keymap(&mut self)

Re-select keymap after a widget completes Port of reselectkeymap() from zle_keymap.c

pub fn read_command(&self, keys: &[u8]) -> Option<Thingy>

Read a key command from the current keymap Port of readcommand() from zle_keymap.c

pub fn get_keybuf(&self) -> &[u8]

Get the key sequence from buffer Port of getkeybuf() from zle_keymap.c

pub fn add_keybuf(&mut self, c: u8)

Add to key buffer Port of addkeybuf() from zle_keymap.c

pub fn clear_keybuf(&mut self)

Clear key buffer

pub fn is_emacs(&self) -> bool

Check if current keymap is emacs

pub fn is_vi_insert(&self) -> bool

Check if current keymap is vi insert

pub fn is_vi_cmd(&self) -> bool

Check if current keymap is vi command

pub fn get_keymap_cmd(&self, km: &Keymap, key: u8) -> Option<Thingy>

Get keymap command for a key Port of getkeymapcmd() from zle_keymap.c

pub fn key_is_prefix(&self, km: &Keymap, key: u8) -> bool

Check if key is prefix in keymap Port of keyisprefix() from zle_keymap.c

pub fn keybind(&mut self, seq: &[u8], thingy: Thingy) -> bool

Bind key in current keymap Port of keybind() from zle_keymap.c

pub fn keyunbind(&mut self, seq: &[u8]) -> bool

Unbind key in current keymap

pub fn scan_keymap(&self, name: &str) -> Vec<(Vec<u8>, String)>

Get bindings for listing Port of scankeymap() / scanbindlist() from zle_keymap.c

pub fn zle_set_keymap(&mut self, name: &str) -> bool

Set keymap via ZLE (zle -K) Port of zlesetkeymap() from zle_keymap.c

pub fn ref_keymap_by_name(&self, name: &str) -> Option<Arc<Keymap>>

Reference keymap by name Port of refkeymap_by_name() from zle_keymap.c

pub fn init_keymaps(&mut self)

Initialize keymaps Port of init_keymaps() from zle_keymap.c

pub fn cleanup_keymaps(&mut self)

Cleanup keymaps Port of cleanup_keymaps() from zle_keymap.c