pub struct ChangeFlags(/* private fields */);Implementations
Sourceimpl ChangeFlags
impl ChangeFlags
Sourcepub const NEXT: ChangeFlags
pub const NEXT: ChangeFlags
Next structure is also part of this change
Sourcepub const PREV: ChangeFlags
pub const PREV: ChangeFlags
Previous structure is also part of this change
Sourceimpl ChangeFlags
impl ChangeFlags
Sourcepub const fn empty() -> ChangeFlags
pub const fn empty() -> ChangeFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ChangeFlags
pub const fn all() -> ChangeFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ChangeFlags>
pub const fn from_bits(bits: u32) -> Option<ChangeFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ChangeFlags
pub const fn from_bits_truncate(bits: u32) -> ChangeFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ChangeFlags
pub const fn from_bits_retain(bits: u32) -> ChangeFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ChangeFlags>
pub fn from_name(name: &str) -> Option<ChangeFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ChangeFlags) -> bool
pub const fn intersects(&self, other: ChangeFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ChangeFlags) -> bool
pub const fn contains(&self, other: ChangeFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ChangeFlags)
pub fn insert(&mut self, other: ChangeFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ChangeFlags)
pub fn remove(&mut self, other: ChangeFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ChangeFlags)
pub fn toggle(&mut self, other: ChangeFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ChangeFlags, value: bool)
pub fn set(&mut self, other: ChangeFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ChangeFlags) -> ChangeFlags
pub const fn intersection(self, other: ChangeFlags) -> ChangeFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ChangeFlags) -> ChangeFlags
pub const fn union(self, other: ChangeFlags) -> ChangeFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ChangeFlags) -> ChangeFlags
pub const fn difference(self, other: ChangeFlags) -> ChangeFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ChangeFlags) -> ChangeFlags
pub const fn symmetric_difference(self, other: ChangeFlags) -> ChangeFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ChangeFlags
pub const fn complement(self) -> ChangeFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ChangeFlags
impl ChangeFlags
Sourcepub const fn iter(&self) -> Iter<ChangeFlags>
pub const fn iter(&self) -> Iter<ChangeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ChangeFlags>
pub const fn iter_names(&self) -> IterNames<ChangeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.