pub struct ModifierFlags(/* private fields */);Implementations
Sourceimpl ModifierFlags
impl ModifierFlags
Sourcepub const MULT: ModifierFlags
pub const MULT: ModifierFlags
A repeat count has been selected
Sourcepub const TMULT: ModifierFlags
pub const TMULT: ModifierFlags
A repeat count is being entered
Sourcepub const VIBUF: ModifierFlags
pub const VIBUF: ModifierFlags
A vi cut buffer has been selected
Sourcepub const VIAPP: ModifierFlags
pub const VIAPP: ModifierFlags
Appending to the vi cut buffer
Sourcepub const NEG: ModifierFlags
pub const NEG: ModifierFlags
Last command was negate argument
Sourcepub const NULL: ModifierFlags
pub const NULL: ModifierFlags
Throw away text for the vi cut buffer
Sourcepub const CHAR: ModifierFlags
pub const CHAR: ModifierFlags
Force character-wise movement
Sourcepub const LINE: ModifierFlags
pub const LINE: ModifierFlags
Force line-wise movement
Sourcepub const PRI: ModifierFlags
pub const PRI: ModifierFlags
OS primary selection for the vi cut buffer
Sourcepub const CLIP: ModifierFlags
pub const CLIP: ModifierFlags
OS clipboard for the vi cut buffer
Sourceimpl ModifierFlags
impl ModifierFlags
Sourcepub const fn empty() -> ModifierFlags
pub const fn empty() -> ModifierFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ModifierFlags
pub const fn all() -> ModifierFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ModifierFlags>
pub const fn from_bits(bits: u32) -> Option<ModifierFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ModifierFlags
pub const fn from_bits_truncate(bits: u32) -> ModifierFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ModifierFlags
pub const fn from_bits_retain(bits: u32) -> ModifierFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ModifierFlags>
pub fn from_name(name: &str) -> Option<ModifierFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ModifierFlags) -> bool
pub const fn intersects(&self, other: ModifierFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ModifierFlags) -> bool
pub const fn contains(&self, other: ModifierFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ModifierFlags)
pub fn insert(&mut self, other: ModifierFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ModifierFlags)
pub fn remove(&mut self, other: ModifierFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ModifierFlags)
pub fn toggle(&mut self, other: ModifierFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ModifierFlags, value: bool)
pub fn set(&mut self, other: ModifierFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ModifierFlags) -> ModifierFlags
pub const fn intersection(self, other: ModifierFlags) -> ModifierFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ModifierFlags) -> ModifierFlags
pub const fn union(self, other: ModifierFlags) -> ModifierFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ModifierFlags) -> ModifierFlags
pub const fn difference(self, other: ModifierFlags) -> ModifierFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ModifierFlags) -> ModifierFlags
pub const fn symmetric_difference(self, other: ModifierFlags) -> ModifierFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ModifierFlags
pub const fn complement(self) -> ModifierFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ModifierFlags
impl ModifierFlags
Sourcepub const fn iter(&self) -> Iter<ModifierFlags>
pub const fn iter(&self) -> Iter<ModifierFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModifierFlags>
pub const fn iter_names(&self) -> IterNames<ModifierFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.