pub struct WidgetFlags(/* private fields */);Expand description
Widget flags
Implementations
Sourceimpl WidgetFlags
impl WidgetFlags
Sourcepub const INT: WidgetFlags
pub const INT: WidgetFlags
Widget is internally implemented
Sourcepub const NCOMP: WidgetFlags
pub const NCOMP: WidgetFlags
New style completion widget
Sourcepub const MENUCMP: WidgetFlags
pub const MENUCMP: WidgetFlags
DON’T invalidate completion list
Sourcepub const YANKAFTER: WidgetFlags
pub const YANKAFTER: WidgetFlags
Yank after cursor
Sourcepub const YANKBEFORE: WidgetFlags
pub const YANKBEFORE: WidgetFlags
Yank before cursor
Sourcepub const YANK: WidgetFlags
pub const YANK: WidgetFlags
Yank (either direction)
Sourcepub const LINEMOVE: WidgetFlags
pub const LINEMOVE: WidgetFlags
Command is a line-oriented movement
Sourcepub const VIOPER: WidgetFlags
pub const VIOPER: WidgetFlags
Widget reads further keys so wait if prefix
Sourcepub const LASTCOL: WidgetFlags
pub const LASTCOL: WidgetFlags
Command maintains lastcol correctly
Sourcepub const KILL: WidgetFlags
pub const KILL: WidgetFlags
Kill command
Sourcepub const KEEPSUFFIX: WidgetFlags
pub const KEEPSUFFIX: WidgetFlags
DON’T remove added suffix
Sourcepub const NOTCOMMAND: WidgetFlags
pub const NOTCOMMAND: WidgetFlags
Widget should not alter lastcmd
Sourcepub const ISCOMP: WidgetFlags
pub const ISCOMP: WidgetFlags
Usable for new style completion
Sourcepub const INUSE: WidgetFlags
pub const INUSE: WidgetFlags
Widget is in use
Sourcepub const FREE: WidgetFlags
pub const FREE: WidgetFlags
Request to free when no longer in use
Sourcepub const NOLAST: WidgetFlags
pub const NOLAST: WidgetFlags
Widget should not alter lbindk
Sourceimpl WidgetFlags
impl WidgetFlags
Sourcepub const fn empty() -> WidgetFlags
pub const fn empty() -> WidgetFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> WidgetFlags
pub const fn all() -> WidgetFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WidgetFlags>
pub const fn from_bits(bits: u32) -> Option<WidgetFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WidgetFlags
pub const fn from_bits_truncate(bits: u32) -> WidgetFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WidgetFlags
pub const fn from_bits_retain(bits: u32) -> WidgetFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WidgetFlags>
pub fn from_name(name: &str) -> Option<WidgetFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WidgetFlags) -> bool
pub const fn intersects(&self, other: WidgetFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WidgetFlags) -> bool
pub const fn contains(&self, other: WidgetFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WidgetFlags)
pub fn insert(&mut self, other: WidgetFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WidgetFlags)
pub fn remove(&mut self, other: WidgetFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WidgetFlags)
pub fn toggle(&mut self, other: WidgetFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WidgetFlags, value: bool)
pub fn set(&mut self, other: WidgetFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WidgetFlags) -> WidgetFlags
pub const fn intersection(self, other: WidgetFlags) -> WidgetFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WidgetFlags) -> WidgetFlags
pub const fn union(self, other: WidgetFlags) -> WidgetFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WidgetFlags) -> WidgetFlags
pub const fn difference(self, other: WidgetFlags) -> WidgetFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: WidgetFlags) -> WidgetFlags
pub const fn symmetric_difference(self, other: WidgetFlags) -> WidgetFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WidgetFlags
pub const fn complement(self) -> WidgetFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WidgetFlags
impl WidgetFlags
Sourcepub const fn iter(&self) -> Iter<WidgetFlags>
pub const fn iter(&self) -> Iter<WidgetFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WidgetFlags>
pub const fn iter_names(&self) -> IterNames<WidgetFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.